@@ -1,6 +1,6 @@
 import sys
 import warnings
-from typing import Generic, Optional, TypeVar, Union, cast
+from typing import Generic, TypeVar, cast
 
 import strawberry
 from django.db import DEFAULT_DB_ALIAS
@@ -27,7 +27,7 @@ PAGINATION_ARG = "pagination"
 @strawberry.type
 class OffsetPaginationInfo:
     offset: int = 0
-    limit: Optional[int] = UNSET
+    limit: int | None = UNSET
 
 
 @strawberry.input
@@ -36,7 +36,7 @@ class OffsetPaginationInput(OffsetPaginationInfo): ...
 
 @strawberry.type
 class OffsetPaginated(Generic[NodeType]):
-    queryset: strawberry.Private[Optional[QuerySet]]
+    queryset: strawberry.Private[QuerySet | None]
     pagination: strawberry.Private[OffsetPaginationInput]
 
     @strawberry.field
@@ -67,7 +67,7 @@ class OffsetPaginated(Generic[NodeType]):
         queryset: QuerySet,
         *,
         info: Info,
-        pagination: Optional[OffsetPaginationInput] = None,
+        pagination: OffsetPaginationInput | None = None,
         **kwargs,
     ) -> Self:
         """Resolve the paginated queryset.
@@ -91,7 +91,7 @@ class OffsetPaginated(Generic[NodeType]):
         """Retrieve tht total count of the queryset without pagination."""
         return get_total_count(self.queryset) if self.queryset is not None else 0
 
-    def get_paginated_queryset(self) -> Optional[QuerySet]:
+    def get_paginated_queryset(self) -> QuerySet | None:
         """Retrieve the queryset with pagination applied.
 
         This will apply the paginated arguments to the queryset and return it.
@@ -110,10 +110,10 @@ class OffsetPaginated(Generic[NodeType]):
 
 
 def apply(
-    pagination: Optional[object],
+    pagination: object | None,
     queryset: _QS,
     *,
-    related_field_id: Optional[str] = None,
+    related_field_id: str | None = None,
 ) -> _QS:
     """Apply pagination to a queryset.
 
@@ -170,8 +170,8 @@ def apply_window_pagination(
     *,
     related_field_id: str,
     offset: int = 0,
-    limit: Optional[int] = UNSET,
-    max_results: Optional[int] = None,
+    limit: int | None = UNSET,
+    max_results: int | None = None,
     reverse: bool = False,
 ) -> _QS:
     """Apply pagination using window functions.
@@ -299,7 +299,7 @@ def get_total_count(queryset: QuerySet) -> int:
 
 
 class StrawberryDjangoPagination(StrawberryDjangoFieldBase):
-    def __init__(self, pagination: Union[bool, UnsetType] = UNSET, **kwargs):
+    def __init__(self, pagination: bool | UnsetType = UNSET, **kwargs):
         self.pagination = pagination
         super().__init__(**kwargs)
 
@@ -343,15 +343,15 @@ class StrawberryDjangoPagination(StrawberryDjangoFieldBase):
         args_prop = super(StrawberryDjangoPagination, self.__class__).arguments
         return args_prop.fset(self, value)  # type: ignore
 
-    def get_pagination(self) -> Optional[type]:
+    def get_pagination(self) -> type | None:
         return OffsetPaginationInput if self._has_pagination() else None
 
     def apply_pagination(
         self,
         queryset: _QS,
-        pagination: Optional[object] = None,
+        pagination: object | None = None,
         *,
-        related_field_id: Optional[str] = None,
+        related_field_id: str | None = None,
     ) -> _QS:
         return apply(pagination, queryset, related_field_id=related_field_id)
 
@@ -360,8 +360,8 @@ class StrawberryDjangoPagination(StrawberryDjangoFieldBase):
         queryset: _QS,
         info: Info,
         *,
-        pagination: Optional[OffsetPaginationInput] = None,
-        _strawberry_related_field_id: Optional[str] = None,
+        pagination: OffsetPaginationInput | None = None,
+        _strawberry_related_field_id: str | None = None,
         **kwargs,
     ) -> _QS:
         queryset = super().get_queryset(queryset, info, **kwargs)
