@@ -1,12 +1,10 @@
-import typing
-
 import strawberry
 
 
 @strawberry.type
 class Query:
     @strawberry.field
-    def hello(self, name: typing.Optional[str] = None) -> str:
+    def hello(self, name: str | None = None) -> str:
         return f"Hello {name or 'world'}"
 
 
